const chalk = require("chalk");

module.exports = function enforceComponentLength(ast, filename) {
  let issues = [];
  const MAX_COMPONENT_LENGTH = 100;

  require("@babel/traverse").default(ast, {
    FunctionDeclaration(path) {
      // Detect function components and measure their length
      const { start, end } = path.node.loc;
      if (end && start && (end.line - start.line) > MAX_COMPONENT_LENGTH) {
        issues.push({
          line: start.line,
          message: `Component is too long (${end.line - start.line} lines). Break it into smaller components.`,
        });
      }
    },
    FunctionExpression(path) {
      // Detect function expressions (e.g., arrow functions) and measure their length
      const { start, end } = path.node.loc;
      if (end && start && (end.line - start.line) > MAX_COMPONENT_LENGTH) {
        issues.push({
          line: start.line,
          message: `Component is too long (${end.line - start.line} lines). Break it into smaller components.`,
        });
      }
    },
    ArrowFunctionExpression(path) {
      // Detect arrow functions and measure their length
      const { start, end } = path.node.loc;
      if (end && start && (end.line - start.line) > MAX_COMPONENT_LENGTH) {
        issues.push({
          line: start.line,
          message: `Component is too long (${end.line - start.line} lines). Break it into smaller components.`,
        });
      }
    },
  });

  if (issues.length > 0) {
    console.log(chalk.red(`\nIssues in ${filename}:`));
    issues.forEach((issue) => {
      console.log(chalk.yellow(`Line ${issue.line}: ${issue.message}`));
    });
  }
};
