const chalk = require("chalk");

module.exports = function enforceFunctionLength(ast, filename) {
  let issues = [];

  require("@babel/traverse").default(ast, {
    FunctionDeclaration(path) {
      const functionName = path.node.id && path.node.id.name;
      const bodyLength = path.node.body.body.length;
      
      // Rule: Function length should not exceed 30 lines
      if (bodyLength > 30) {
        issues.push({
          line: path.node.loc.start.line,
          message: `Function "${functionName}" has too many lines of code.`,
          suggestion: `The function "${functionName}" has ${bodyLength} lines, which may be too long. Consider refactoring it into smaller, more manageable functions.`,
        });
      }
    },

    ArrowFunctionExpression(path) {
      const bodyLength = path.node.body.body ? path.node.body.body.length : 0;
      
      // Rule: Arrow function length should not exceed 30 lines
      if (bodyLength > 30) {
        issues.push({
          line: path.node.loc.start.line,
          message: `Arrow function has too many lines of code.`,
          suggestion: `This arrow function has ${bodyLength} lines. Consider breaking it into smaller functions.`,
        });
      }
    }
  });

  if (issues.length > 0) {
    console.log(chalk.red(`\nIssues in ${filename}:`));
    issues.forEach((issue) => {
      console.log(chalk.yellow(`Line ${issue.line}: ${issue.message}`));
      console.log(chalk.green(`Suggestion: ${issue.suggestion}`));
    });
  }
};
