const chalk = require("chalk");

module.exports = function enforceNoConsole(ast, filename) {
  let issues = [];

  require("@babel/traverse").default(ast, {
    CallExpression(path) {
      if (
        path.node.callee.object &&
        path.node.callee.object.name === "console" &&
        path.node.callee.property.name === "log"
      ) {
        issues.push({
          line: path.node.loc.start.line,
          message: "Avoid using console.log in the code.",
        });
      }
    },
  });

  if (issues.length > 0) {
    console.log(chalk.red(`\nIssues in ${filename}:`));
    issues.forEach((issue) => {
      console.log(chalk.yellow(`Line ${issue.line}: ${issue.message}`));
    });
  }
};
