const chalk = require("chalk");
const { default: traverse } = require("@babel/traverse");

module.exports = function enforceStateInitialization(ast, filename) {
  let issues = [];

  traverse(ast, {
    VariableDeclarator(path) {
      const id = path.node.id;
      const init = path.node.init;

      // Check if the initialization is a useState call
      if (
        init &&
        init.type === "CallExpression" &&
        init.callee.name === "useState" &&
        init.arguments.length === 0
      ) {
        // If there are no arguments passed to useState
        issues.push({
          line: path.node.loc.start.line,
          message: `State initialized without a default value.`,
          suggestion: `State should always be initialized with a default value, such as an empty array, object, or a specific value (e.g., useState([]), useState(''), useState(0)).`,
        });
      }
    }
  });

  if (issues.length > 0) {
    console.log(chalk.red(`\nIssues in ${filename}:`));
    issues.forEach((issue) => {
      console.log(chalk.yellow(`Line ${issue.line}: ${issue.message}`));
      console.log(chalk.green(`Suggestion: ${issue.suggestion}`));
    });
  }
};
