const { execSync } = require("child_process");
const path = require("path");
const fs = require("fs");

// Get the user's project directory
const userProjectDir = path.resolve(process.cwd());

// Check if ESLint configuration exists, and create one if it doesn't
const eslintConfigPath = path.join(userProjectDir, "eslint.config.js");

if (!fs.existsSync(eslintConfigPath)) {
  fs.writeFileSync(
    eslintConfigPath,
    `
import reactCodingStandards from "eslint-plugin-react-coding-standards";

export default [
  {
    plugins: {
      "react-coding-standards": reactCodingStandards,
    },
    rules: {
      "react-coding-standards/enforce-function-length": "warn",
      "react-coding-standards/enforce-redux-action-naming": "warn",
      "react-coding-standards/enforce-useeffect-dependencies": "warn",
    },
  },
];
    `,
    "utf-8"
  );
  console.log("Default ESLint configuration created at eslint.config.js");
} else {
  console.log("Using existing ESLint configuration.");
}

// Run ESLint
try {
  console.log("Running ESLint with react-coding-standards...");
  execSync(`npx eslint ${userProjectDir} --no-eslintrc`, {
    stdio: "inherit",
  });
  console.log("Linting completed successfully!");
} catch (error) {
  console.error("Error running ESLint:", error.message);
  process.exit(1);
}
